@@ -246,8 +246,8 @@ class _CCMApp(_app._App, _typesystem.No_Type_System_Mixin):
     supports_configs = False
     supports_components = False
     reportablerestbase='rpt/repository'
-    supports_reportable_rest = False
-    reportable_rest_status = "Application supports Reportable REST but not implemented here yet"
+    supports_reportable_rest = True
+    reportable_rest_status = "Application supports Reportable REST but represt for ccm not fully tested/working"
     artifact_formats = [ # For RR
         'foundation'
         ,'scm'
@@ -257,6 +257,20 @@ class _CCMApp(_app._App, _typesystem.No_Type_System_Mixin):
         ]
     identifier_name = 'id'
     identifier_uri = 'dcterms:identifier'
+    # these are schema xpath paths of known queryable and unqueryable paths
+    _rr_queryable = [
+        'workitem/projectArea/name',
+        'workitem/workItem/id',
+        'workitem/workItem/type/id',
+        'workitem/workItem/target/name',
+        'workitem/workItem/tags',
+        'workitem/workItem/state/id',
+        'workitem/workItem/state/group',
+    ]
+    _rr_unqueryable = [
+        'workitem/workItem/type',
+        'workitem/workItem/teamArea',
+    ]
 
     def __init__(self, server, contextroot, jts=None):
         super().__init__(server, contextroot, jts=jts)
@@ -272,17 +286,19 @@ class _CCMApp(_app._App, _typesystem.No_Type_System_Mixin):
         return result
 
     @classmethod
-    def add_represt_arguments( cls, subparsers ):
+    def add_represt_arguments( cls, subparsers, common_args ):
         '''
         NOTE this is called on the class (i.e. is a class method) because at this point don't know which app with be queried
         '''
-        parser_ccm = subparsers.add_parser('ccm', help='CCM Reportable REST actions')
+        parser_ccm = subparsers.add_parser('ccm', help='CCM Reportable REST actions', parents=[common_args])
         
         parser_ccm.add_argument('artifact_format', choices=cls.artifact_formats, default=None, help=f'CCM artifact format - possible values are {", ".join(cls.artifact_formats)}')
 
         # SCOPE settings
         parser_ccm.add_argument('-p', '--project', default=None, help='Scope: Name of project - required when using module/collection/view/resource/typename ID/typename as a filter')
 
+        parser_ccm.add_argument('-r', '--report', action='store_true', help='Report the fields available')
+
 #        # Source Filters - only use one of these at once - all require a project and configuration!
 #        rmex1 = parser_ccm.add_mutually_exclusive_group()
 #        rmex1.add_argument('-c', '--collection', default=None, help='Sub-scope: RM: Name or ID of collection - you need to provide the project and local/global config')
@@ -294,7 +310,7 @@ class _CCMApp(_app._App, _typesystem.No_Type_System_Mixin):
 #        # Output FILTER settings - only use one of these at once
 #        parser_ccm.add_argument('-a', '--all', action="store_true", help="Filter: Report all resources")
 #        parser_ccm.add_argument('-d', '--modifiedsince', default=None, help='Filter: only return items modified since this date in format 2021-01-31T12:34:26Z')
-#    #    parser_ccm.add_argument('-f', '--fields', action="store_true", help="Filter using xpath (doesn't work for DNG?)")
+        parser_ccm.add_argument('-f', '--fields', default=None, help="Filter using xpath")
 #        parser_ccm.add_argument('-x', '--expandEmbeddedArtifacts', action="store_true", help="Filter: Expand embedded artifacts")
         
 #        # various options
@@ -303,9 +319,9 @@ class _CCMApp(_app._App, _typesystem.No_Type_System_Mixin):
 #        parser_ccm.add_argument('--pagesize', default=100, type=int, help="Page size for results paging (default 100)")    
         
 #        # Output controls - only use one of these at once!
-#        rmex2 = parser_ccm.add_mutually_exclusive_group()
+        rmex2 = parser_ccm.add_mutually_exclusive_group()
 #        rmex2.add_argument('--attributes', default=None, help="Output: Comma separated list of attribute names to report (requires specifying project and configuration)")
-#        rmex2.add_argument('--schema', action="store_true", help="Output: Report the schema")
+        rmex2.add_argument('--schema', action="store_true", help="Output: Report the schema")
 #        rmex2.add_argument('--titles', action="store_true", help="Output: Report titles")
 #        rmex2.add_argument('--linksOnly', action="store_true", help="Output: Report links only")
 #        rmex2.add_argument('--history', action="store_true", help="Output: Report history")
@@ -313,14 +329,69 @@ class _CCMApp(_app._App, _typesystem.No_Type_System_Mixin):
 #        rmex2.add_argument('--signaturePage', action="store_true", help="Output: Report signature page variables")
 #    #    rmex2.add_argument('--size', action="store_true", help="Output: Set size (required for ???)")
 
-    def process_represt_arguments( self, args ):
+    def process_represt_arguments( self, args, allapps ):
         '''
         Process above arguments, returning a dictionayt of parameters to add to the represt base URL
         NOTE this does have some dependency on thje overall 
         
         NOTE this is called on an instance (i.e. not a class method) because by now we know which app is being queried
         '''
-        params = {}
-        url = ""
-        return (url,params)
+        queryparams = {}
+        queryurl = ""
+        queryheaders={}
+        
+        if args.schema:
+            queryparams['metadata'] = 'schema'
+            
+        queryurl = self.reluri(self.reportablerestbase) + "/"+ args.artifact_format
+            
+        if args.report:
+            typestodo = []
+            # get the schema, walk it building the tree of fields
+            schema_x = self.execute_get_xml(queryurl+"?metadata=schema").getroot()
+#            print( f"{schema_x.tag=}" )
+#            print( f"{schema_x=}" )
+            el_x = rdfxml.xml_find_element( schema_x, "./xs:element" )
+            typestodo=[el_x.get('type')]
+            knowntypes={el_x.get('type'):[el_x.get('type')]} # contains path to [parent
+            fieldlist = []
+            while typestodo:
+#                print( f"{knowntypes=}" )
+                typetofind = typestodo.pop(0)
+                type_x = rdfxml.xml_find_element( schema_x, f'.//xs:complexType[@name="{typetofind}"]' )
+#                print( f"Finding {typetofind=} {type_x=}" )
+                if type_x is not None:
+                    seq_x = rdfxml.xml_find_element( type_x, './xs:sequence' )
+                    type_name = type_x.get('name')
+                    name_name = type_x.get('type')
+    #                print( f"{type_name=}" )
+                    if seq_x is not None:
+#                        print( f"{typetofind=} {type_name=} {name_name=}" )
+                        for subel_x in rdfxml.xml_find_elements(seq_x,'./xs:element'):
+                            subeltype = subel_x.get('type')
+                            subelname = subel_x.get('name')
+    #                        print( f"{subeltype=}" )
+    #                        print( f"{subelname=}" )
+                            typestr = ""
+                            if subeltype.startswith( "xs:"):
+#                                print( f"Type {typetofind} Found endpoint {subelname} {subeltype}" )
+                                typestr = " "+subeltype                            
+                                fieldpath = "/".join(knowntypes[type_name]+[subelname]) + typestr
+                                if fieldpath not in fieldlist:
+#                                    print( f"Adding {fieldpath}" )
+                                    fieldlist.append(fieldpath)
+                                
+                            elif subeltype not in knowntypes:
+                                typestodo.append(subeltype) 
+#                                print( f"Type {typetofind} Queued {subelname=} {subeltype=}" )
+                                knowntypes[subeltype] = knowntypes[type_name]+[subelname]
+    #                        print( f'{"/".join(knowntypes[subeltype]+[subelname])}' )
+                                
+                    else:
+                        raise Exception( f"xs:sequence not found in schema for type {typetofind}" )
+            print( "\n".join(sorted(fieldlist) ) )
 
+        if args.fields:
+            queryparams['fields'] = args.fields
+
+        return (queryurl,queryparams,queryheaders)
